"use strict";
/**
 * Copyright 2018 Alexander Sychev
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
Object.defineProperty(exports, "__esModule", { value: true });
/** Binary number system radix value */
exports.BINARY_RADIX = 2;
/** Hex number system radix value */
exports.HEX_RADIX = 16;
/** Decimal number system radix value */
exports.DECIMAL_RADIX = 10;
/** Minimal available radix value */
exports.MIN_RADIX_VALUE = exports.BINARY_RADIX;
/** Maximal available radix value */
exports.MAX_RADIX_VALUE = 36;
/** Returns "true" if numeric value is correct radix value */
function isRadixValue(radix) {
    return Number.isInteger(radix) && radix >= exports.MIN_RADIX_VALUE && radix <= exports.MAX_RADIX_VALUE;
}
exports.isRadixValue = isRadixValue;
// Assertion functions
function assertValue(value) {
    if (typeof value !== 'number' && typeof value !== 'string') {
        throw new Error('First argument ("value") must be number or string');
    }
    if (typeof value === 'number' && !Number.isInteger(value)) {
        throw new Error('Value must be integer');
    }
}
function assertRadix(radix, type) {
    if (!isRadixValue(radix)) {
        throw new Error("Radix to convert " + type + " is not a radix value (integer from 2 to 36)");
    }
}
function assertNumberValue(value, radix) {
    if (typeof value === 'number' && radix !== exports.DECIMAL_RADIX) {
        throw new Error('Value with type "number" can be converted only from decimal system');
    }
}
/** Common function to convert value from one positional system to another */
function convert(value, from, to) {
    assertValue(value);
    assertRadix(from, 'from');
    assertRadix(to, 'to');
    assertNumberValue(value, from);
    return parseInt(String(value).toUpperCase(), from).toString(to).toUpperCase();
}
exports.convert = convert;
